local LOCATION = GetModConfigData("LOCATION")

local Image = GLOBAL.require("widgets/image")
local ImageButton = GLOBAL.require("widgets/imagebutton")
local ConsoleScreen = GLOBAL.require("screens/consolescreen")

Assets = {
	Asset("ATLAS", "images/ui2.xml"),
	Asset("IMAGE", "images/ui2.tex"),
}

local dir_vert = LOCATION.dir_vert
local dir_horiz = -1
local anchor_vert = 1
local anchor_horiz = 1
local margin_dir_vert = 1
local margin_dir_horiz = 1
local margin_size_x = 0
local margin_size_y = 0

local function relocateButton(controls, screensize, resizescale, oldrootscale, button)
	local hudscale = controls.top_root:GetScale()
	local screenw_full, screenh_full = GLOBAL.unpack(screensize)
	local screenw = screenw_full/hudscale.x
	local screenh = screenh_full/hudscale.y
	local button_h, button_w = button:GetSize()
	button_h = button_h * button:GetLooseScale() --scaled the same as defined in InitButtons
	button_w = button_w * button:GetLooseScale()
	
	if LOCATION.pos == "TL" then margin_size_y = (button_h * -1) end
	
	--The default position of the panel which is what everything is based on
	button.homePos = GLOBAL.Vector3(
		(anchor_horiz*button_w/2)+(dir_horiz*screenw/2)+(margin_dir_horiz*margin_size_x),
		(anchor_vert*button_h/2)+(dir_vert*screenh/2)+(margin_dir_vert*margin_size_y),
		0
	)
	
	button:SetPosition(button.homePos)
end

local function AddButton(controls)
	local button = controls.top_root:AddChild(ImageButton("images/hud.xml","inv_slot_spoiled.tex","inv_slot.tex","inv_slot_spoiled.tex","inv_slot_spoiled.tex","inv_slot_spoiled.tex"))--("images/ui.xml","portrait_bg.tex"))
	button:SetScale(.63)
	button:MoveToFront()
	button.isHidden = false
	button.hasMoved = false
	
	local buttonImage = Image("images/ui2.xml","portrait_bg.tex")
	buttonImage:SetScale(.55)
	button:AddChild(buttonImage)
	button:SetOnClick(function(inst) GLOBAL.TheFrontEnd:PushScreen(ConsoleScreen()) end)
	
	local screensize = {GLOBAL.TheSim:GetScreenSize()}
	local rootscale = controls.top_root:GetScale()
	relocateButton(controls, screensize, GLOBAL.Vector3(1,1,1), GLOBAL.Vector3(1,1,1), button)
	
	local OnUpdateOriginal = controls.OnUpdate
	controls.OnUpdate = function(self, dt)
		OnUpdateOriginal(self, dt)
		local curscreensize = {GLOBAL.TheSim:GetScreenSize()}
		-- Use ratio (curscreensize/screensize) to translate old position of button to new screen size
		if curscreensize[1] ~= screensize[1] or curscreensize[2] ~= screensize[2] then --if the screen has changed, then reposition the panel
			local resizescale = GLOBAL.Vector3(curscreensize[1]/screensize[1], curscreensize[2]/screensize[2], 0)
			relocateButton(controls, curscreensize, resizescale, rootscale, button)
			screensize = curscreensize
			rootscale = controls.top_root:GetScale()
		end
	end	
end

AddClassPostConstruct("widgets/controls", AddButton)